@@ -17,7 +17,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	<stdio.h>
 #include	<string.h>
 #include	<stdlib.h>
-#include	<getopt.h>
+#include	<unistd.h>
 #include	<ctype.h>
 #include	<errno.h>
 #include	"cdb.h"
