@@ -17,4 +17,4 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 void options_init(options *o);
 void options_destroy(options *o);
 void options_set(options *o, int argc, char *argv[]);
-void options_announce(options *o);
+void options_announce(FILE *out, options *o);
