@@ -16,15 +16,6 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #ifndef	ELC_RULES_H
 #define	ELC_RULES_H
 
-#if 0				/* using checksets now to store sets of
-				 * options for checks to do, with rules
-				 * manipulated in a regular unsigned long
-				 * at runtime */
-typedef struct rule {
-  unsigned long	flags;
-} rule;
-#endif
-
 typedef enum ruleflag {
   RULE_IGNORE		 = 0x01,
   RULE_NOCHILDREN	 = 0x02,
